@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0103';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -44,6 +44,8 @@ sub generate {
     $chord ||= 'C';
     $num ||= 4;
 
+    print "* CHORD: $chord\n" if $self->verbose;
+
     my $scale = $chord =~ /^[A-G][#b]?m/ ? 'minor' : 'major';
 
     # Parse the chord
@@ -66,14 +68,14 @@ sub generate {
         if (not any { $_ eq $n } @named) {
             my $x = Music::Note->new($n, 'ISO')->format('midinum');
             push @pitches, $x;
-            print "$chord ADDS: $n\n" if $self->verbose;
+            print "\tADD: $n\n" if $self->verbose;
         }
     }
     @pitches = sort { $a <=> $b } @pitches; # Pitches are midi numbers
 
     # Determine if we should skip certain notes given the chord flavor
     my @tones = get_scale_notes($chord_note, $scale);
-    print "SCALE: ",ddc(\@tones) if $self->verbose;
+    print "\tSCALE: ",ddc(\@tones) if $self->verbose;
     my @fixed;
     for my $p (@pitches) {
         my $x = Music::Note->new($p, 'midinum')->format('isobase');
@@ -90,7 +92,7 @@ sub generate {
             ||
             ($flavor =~ /aug/ && $x eq $tones[6])
         ) {
-            print "DROP: $x\n" if $self->verbose;
+            print "\tDROP: $x\n" if $self->verbose;
             next;
         }
         push @fixed, $p;
@@ -98,7 +100,7 @@ sub generate {
 
     # Debugging:
     @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @fixed;
-    print "NOTES: ",ddc(\@named) if $self->verbose;
+    print "\tNOTES: ",ddc(\@named) if $self->verbose;
 
     my $voice = Music::VoiceGen->new(
         pitches   => \@fixed,
@@ -113,7 +115,7 @@ sub generate {
 
     # Show them what they've won, Bob!
     @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @chosen;
-    print "CHOSEN: $chord: ",ddc(\@named) if $self->verbose;
+    print "\tCHOSEN: ",ddc(\@named) if $self->verbose;
 
     return \@chosen;
 }
@@ -132,7 +134,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0102
+version 0.0103
 
 =head1 SYNOPSIS
 
@@ -140,7 +142,7 @@ version 0.0102
 
   my $bassline = MIDI::Bassline::Walk->new(verbose => 1);
 
-  my $notes = $bassline->generate('C7b5', 4);
+  my $notes = $bassline->generate('C7b5', 8);
 
   # MIDI:
   # $score->n('qn', $_) for @$notes;
@@ -149,10 +151,14 @@ version 0.0102
 
 C<MIDI::Bassline::Walk> generates randomized, walking basslines.
 
-The logic (and music theory) implemented here, definitely generates
-some sour notes.  And sometimes too much!  This is an approximate
-composition tool, and not a drop-in bass player.  Import the rendered
-MIDI into a DAW and alter things until they are suitable.
+The logic (and music theory) implemented here, can generate some sour
+notes.  And sometimes too much!  This is an approximate composition
+tool, and not a drop-in bass player.  Import the rendered MIDI into a
+DAW and alter things until they are suitable.
+
+The chords recognized by this module, are those known by
+L<Music::Chord::Note>.  Please see the source of that module for the
+list.
 
 =head1 ATTRIBUTES
 
